==> haskell-test-framework-smallcheck-0.2-182-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework-smallcheck
version:              0.2
visibility:           public
id:                   test-framework-smallcheck-0.2-DJawhh2wSC6ssUGh3qpXN
key:                  test-framework-smallcheck-0.2-DJawhh2wSC6ssUGh3qpXN
license:              BSD-3-Clause
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/smallcheck
synopsis:             Support for SmallCheck tests in test-framework
description:          Support for SmallCheck tests in test-framework
category:             Testing
abi:                  15a8b8961791718be06125519f37e388
exposed:              True
exposed-modules:      Test.Framework.Providers.SmallCheck
import-dirs:          /usr/lib/ghc-9.0.2/site-local/test-framework-smallcheck-0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.2/test-framework-smallcheck-0.2

hs-libraries:         HStest-framework-smallcheck-0.2-DJawhh2wSC6ssUGh3qpXN
depends:
    base-4.15.1.0 smallcheck-1.2.1-BwqIzlGIaGNGxc4nvHJ9hQ
    test-framework-0.8.2.0-FhyGX0i5Sjw8FVIx27oHB1 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-smallcheck-0.2-185-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework-smallcheck
version:              0.2
visibility:           public
id:                   test-framework-smallcheck-0.2-KYX2aS9p6kQGeomugMHsrl
key:                  test-framework-smallcheck-0.2-KYX2aS9p6kQGeomugMHsrl
license:              BSD-3-Clause
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/smallcheck
synopsis:             Support for SmallCheck tests in test-framework
description:          Support for SmallCheck tests in test-framework
category:             Testing
abi:                  f649f76294ca88b9279230b54c2e8ebd
exposed:              True
exposed-modules:      Test.Framework.Providers.SmallCheck
import-dirs:          /usr/lib/ghc-9.0.2/site-local/test-framework-smallcheck-0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.2/test-framework-smallcheck-0.2

hs-libraries:         HStest-framework-smallcheck-0.2-KYX2aS9p6kQGeomugMHsrl
depends:
    base-4.15.1.0 smallcheck-1.2.1-1ukqtPUt8ZxBzNjd69ZgGy
    test-framework-0.8.2.0-AJHLptpEpJDCZda3onIz2d transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
